#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

#  
# The sample contained herein is provided to you "AS IS".
# It is furnished by IBM as a sample script

from java.io import FileInputStream, IOException
from java.util import Properties
from os.path import abspath, normpath, exists
import os
import sys
import java.lang.System
from java.lang import Thread

errorCode = ""
errorInfo = ""


#*******************************************************************************************************
# Procedure to Enable RACF Bridge
#*******************************************************************************************************

def configRACFBridge():


   try:
      AdminTask.createIdMgrCustomRepository ('-id urbRACF -adapterClassName com.ibm.ws.wim.adapter.urbridge.URBridge')
      AdminTask.addIdMgrRepositoryBaseEntry ('-id urbRACF -name o=local')
      AdminTask.addIdMgrRealmBaseEntry('-name defaultWIMFileBasedRealm -baseEntry o=local')
   except:
      _type_, _value_, _tbck_ = sys.exc_info()
      errorInfo = str(_value_)
      print errorInfo
      return 1
   #endExcept

   return 0

#endDef


#*******************************************************************************************************
# Procedure to Set  SAF Authorization
#*******************************************************************************************************

def configSAFAuthorization( inValue ):

  security = AdminConfig.list("Security")
  properties = AdminConfig.showAttribute( security, "properties")
  properties = properties.replace('[','')
  properties = properties.replace(']','')
  properties = properties.split(' ')

  for property in properties:
       name=AdminConfig.showAttribute(property, "name")
       if name == "com.ibm.security.SAF.authorization" :
           value=AdminConfig.showAttribute(property, "value")
           if (value != inValue ) :          
               valAttr = ["value", inValue]
               propAttr = [valAttr]
               AdminConfig.modify(property, propAttr )
               print "Updating com.ibm.security.SAF.authorization"
           #endIf
       #endIf
  #endFor    

  AdminConfig.modify(security, [['enforceJava2Security', 'false']])

  registries = AdminConfig.list("UserRegistry")
  registries = registries.split(java.lang.System.getProperty("line.separator"))

  str = "WIMUserRegistry_1)"
  value=AdminConfig.showAttribute(security, "activeUserRegistry")
  if (value.endswith(str)) :
      print "FederatedRepository already Active"
  else: 
  	for registry in registries:
    	   if (registry.endswith(str)) :
        	   AdminConfig.modify(security, [['activeUserRegistry',  registry ]])
           	   print "Updating Active Registry to Federated Repository"
       	#endIf
  	#endFor    
  #endIf

  return 0

#endDef



#*******************************************************************************************************
# Procedure to Enable SAF Mapping
#*******************************************************************************************************

def configSAFMapping():

  security = AdminConfig.list("Security")
  cfg = AdminConfig.showAttribute(security, "systemLoginConfig" )

  loginEntries = AdminConfig.showAttribute(cfg, "entries" )
  loginEntries = loginEntries.replace('[','')
  loginEntries = loginEntries.replace(']','')
  loginEntries = loginEntries.split(' ')


  for entry in loginEntries:
	   alias = AdminConfig.showAttribute(entry, "alias")

  #endFor    


  for entry in loginEntries:
	  alias = AdminConfig.showAttribute(entry, "alias")      
 	  if  (alias == "WEB_INBOUND") or (alias == "RMI_INBOUND") or (alias == "DEFAULT") :
            if (isSAFMappingEnabled(entry) == 0 ) :
                 enableSAFMapping( entry)
                 print "SAF Mapping enabled for " + alias
            #endIf
      #endIf
  #endFor    

  return 0

#endDef

#*******************************************************************************************************
# Procedure to  Enable SAF Mapping
#*******************************************************************************************************

def enableSAFMapping( entry ):

  

  vmmJAASLoginModuleId = AdminConfig.create("JAASLoginModule",entry,[["moduleClassName", SAFModule ]])
  vmmPropertyId = AdminConfig.create("Property", vmmJAASLoginModuleId,[[ "name", "useWSPrincipalName" ], [ "value", "true"]] )
  AdminConfig.modify(vmmJAASLoginModuleId,[["authenticationStrategy","REQUIRED"]])
  mapJAASLoginModuleId = AdminConfig.create("JAASLoginModule",entry,[["moduleClassName", "com.ibm.ws.security.common.auth.module.MapPlatformSubject" ]])
  AdminConfig.modify(mapJAASLoginModuleId,[["authenticationStrategy","REQUIRED"]])

  return 0

#endDef


#*******************************************************************************************************
# Procedure to test if Enable SAF Mapping Enabled
#*******************************************************************************************************

def isSAFMappingEnabled( entry ):

  loginEntries = AdminConfig.showAttribute(entry, "loginModules")
  loginEntries = loginEntries.replace('[','')
  loginEntries = loginEntries.replace(']','')
  loginEntries = loginEntries.split(' ')
  alias = AdminConfig.showAttribute(entry, "alias")

  for module in loginEntries:
       name=AdminConfig.showAttribute(module, "moduleClassName")
       if (name == SAFModule) :
         print "SAF Mapping Already enabled for " + alias
         return 1
       elif (name == SAFModuleSample ) :
         AdminConfig.modify(module, [['moduleClassName',  SAFModule ]])
         print "Updating SAF Mapping for " + alias
         return 1
       #endIf
  #endFor    

  return 0

#endDef


#*******************************************************************************************************
# MAIN
#*******************************************************************************************************

#
# Commandline parameter handling
#
#"com.ibm.websphere.wim.VMMSAFMappingModule"
SAFModuleProd    = "com.ibm.wsspi.wim.VMMSAFMappingModule"
SAFModuleSample  = "com.ibm.websphere.wim.SampleVMMSAFMappingModule"

try:
#   Check if ++APAR PM44359 is available
    cl=Thread.currentThread().getContextClassLoader().loadClass(SAFModuleProd)
    SAFModule  = SAFModuleProd
except:
#   Use Sample Module
    SAFModule  = SAFModuleSample


racf	   = 1
saf		   = "true"	
map		   = 1	

argc       = len(sys.argv)
display    = 0
uninstall  = 0
help       = 0

i = 0  #forStart
while ( i < argc ):  #forTest
        arg = sys.argv[i]
        if (arg == "-saf"):
          saf="false"
        elif (arg == "+saf"):
          saf="true"
        elif (arg == "-zhelp"):
          help = 1
        elif (arg == "-display"):
          display = 1
        else:
          argerr = "Invalid command line argument: "+arg
        #endElse 
        i += 1  #forNext
#endWhile  (#endFor)


if (help):
  print "                              '-zhelp     '                 "
  sys.exit()
#endIf 

if ( ("argerr" in locals().keys() or "argerr" in globals().keys())  ):
        print argerr
        sys.exit()
#endIf 



isnd = AdminTask.isFederated()

if (isnd == 'true'):
    dmNodeName     = java.lang.System.getProperty ( "local.node" )
    
#------------------------------------------------------------------------------
# Audit Arguments


if (display):
        print " '-display'        <DisplayOnly>      "
#endIf 

print "--------------------------------------------------------------------------"

print "Configuring SAF Mapping Module: " + SAFModule 

 
configRACFBridge()

configSAFAuthorization(saf)

configSAFMapping()

if (display == 0):
  print "--------------------------------------------------------------------------"
  print "Saving Configuration"
  AdminConfig.save( )
#endIf 

#Done
